Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: chrome/browser/storage_monitor/test_storage_monitor_win.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix some includes from recent merge. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/test_storage_monitor_win.h
diff --git a/chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h b/chrome/browser/storage_monitor/test_storage_monitor_win.h
similarity index 68%
rename from chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h
rename to chrome/browser/storage_monitor/test_storage_monitor_win.h
index 314ab07648a827306ad7e5f3c7b5a8847ec378ef..e1a2229beb52058afe9df4ad058ce6ad6cde52a0 100644
--- a/chrome/browser/storage_monitor/test_removable_device_notifications_window_win.h
+++ b/chrome/browser/storage_monitor/test_storage_monitor_win.h
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// This file contains a subclass of RemovableDeviceNotificationsWindowWin to
// simulate device changed events for testing.
#ifndef CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
vandebo (ex-Chrome) 2013/03/01 19:47:39 update include guards.
@@ -11,7 +11,7 @@
#include <windows.h>
#include "base/memory/ref_counted.h"
-#include "chrome/browser/storage_monitor/removable_device_notifications_window_win.h"
+#include "chrome/browser/storage_monitor/storage_monitor_win.h"
namespace chrome {
namespace test {
@@ -19,21 +19,21 @@ namespace test {
class TestPortableDeviceWatcherWin;
class TestVolumeMountWatcherWin;
-class TestRemovableDeviceNotificationsWindowWin
- : public RemovableDeviceNotificationsWindowWin {
+class TestStorageMonitorWindowWin
+ : public StorageMonitorWin {
vandebo (ex-Chrome) 2013/03/01 19:47:39 nit: line wrap.
public:
- TestRemovableDeviceNotificationsWindowWin(
+ TestStorageMonitorWindowWin(
TestVolumeMountWatcherWin* volume_mount_watcher,
TestPortableDeviceWatcherWin* portable_device_watcher);
- virtual ~TestRemovableDeviceNotificationsWindowWin();
+ virtual ~TestStorageMonitorWindowWin();
void InjectDeviceChange(UINT event_type, DWORD data);
VolumeMountWatcherWin* volume_mount_watcher();
private:
- DISALLOW_COPY_AND_ASSIGN(TestRemovableDeviceNotificationsWindowWin);
+ DISALLOW_COPY_AND_ASSIGN(TestStorageMonitorWindowWin);
};
} // namespace test
@@ -2,7 +2,7 @@
// found in the LICENSE file.
//
-// This file contains a subclass of RemovableDeviceNotificationsWindowWin to
+// This file contains a subclass of StorageMonitorWindowWin to
// simulate device changed events for testing.
#ifndef CHROME_BROWSER_STORAGE_MONITOR_TEST_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_

Powered by Google App Engine
This is Rietveld 408576698